@@ -10,12 +10,13 @@ import os
 
 pjoin = os.path.join
 
+from jupyter_core.utils import ensure_async
 from tornado import web
 
-from ...base.handlers import APIHandler
-from ...utils import ensure_async, url_path_join, url_unescape
 from jupyter_server.auth import authorized
 
+from ...base.handlers import APIHandler
+from ...utils import url_path_join, url_unescape
 
 AUTH_RESOURCE = "kernelspecs"
 
@@ -49,13 +50,18 @@ def is_kernelspec_model(spec_dict):
 
 
 class KernelSpecsAPIHandler(APIHandler):
+    """A kernel spec API handler."""
+
     auth_resource = AUTH_RESOURCE
 
 
 class MainKernelSpecHandler(KernelSpecsAPIHandler):
+    """The root kernel spec handler."""
+
     @web.authenticated
     @authorized
     async def get(self):
+        """Get the list of kernel specs."""
         ksm = self.kernel_spec_manager
         km = self.kernel_manager
         model = {}
@@ -82,9 +88,12 @@ class MainKernelSpecHandler(KernelSpecsAPIHandler):
 
 
 class KernelSpecHandler(KernelSpecsAPIHandler):
+    """A handler for an individual kernel spec."""
+
     @web.authenticated
     @authorized
     async def get(self, kernel_name):
+        """Get a kernel spec model."""
         ksm = self.kernel_spec_manager
         kernel_name = url_unescape(kernel_name)
         try:
