@@ -1,4 +1,5 @@
 import os
+import shutil
 import sys
 import time
 from itertools import combinations
@@ -52,6 +53,39 @@ def _make_dir(jp_contents_manager, api_path):
         print("Directory already exists: %r" % os_path)
 
 
+def _make_big_dir(contents_manager, api_path):
+    # make a directory that is over 100 MB in size
+    os_path = contents_manager._get_os_path(api_path)
+    try:
+        os.makedirs(os_path)
+
+        with open(f"{os_path}/demofile.txt", "a") as textFile:
+            textFile.write(
+                """
+            Lorem ipsum dolor sit amet, consectetur adipiscing elit,
+            sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.
+            Ut enim ad minim veniam, quis nostrud exercitation ullamco
+            laboris nisi ut aliquip ex ea commodo consequat.
+            Duis aute irure dolor in reprehenderit in voluptate
+            velit esse cillum dolore eu fugiat nulla pariatur.
+            Excepteur sint occaecat cupidatat non proident,
+            sunt in culpa qui officia deserunt mollit anim id est laborum.
+            """
+            )
+
+        num_sub_folders = contents_manager.max_copy_folder_size_mb * 10
+        for i in range(num_sub_folders):
+            os.makedirs(f"{os_path}/subfolder-{i}")
+            for j in range(200):
+                shutil.copy(
+                    f"{os_path}/demofile.txt",
+                    f"{os_path}/subfolder-{i}/testfile{j}.txt",
+                )
+
+    except OSError as err:
+        print("Directory already exists", err)
+
+
 def symlink(jp_contents_manager, src, dst):
     """Make a symlink to src from dst
 
@@ -163,6 +197,9 @@ def test_get_os_path(jp_file_contents_manager_class, tmp_path):
     fs_path = os.path.join(fm.root_dir, "test.ipynb")
     assert path == fs_path
 
+
+@pytest.mark.skipif(os.name == "nt", reason="Posix only")
+def test_get_os_path_posix(jp_file_contents_manager_class, tmp_path):
     fm = jp_file_contents_manager_class(root_dir=str(tmp_path))
     path = fm._get_os_path("////test.ipynb")
     fs_path = os.path.join(fm.root_dir, "test.ipynb")
@@ -259,8 +296,7 @@ async def test_403(jp_file_contents_manager_class, tmp_path):
         assert e.status_code == 403
 
 
-@pytest.mark.skipif(sys.platform.startswith("win"), reason="Can't test hidden files on Windows")
-async def test_400(jp_file_contents_manager_class, tmp_path):
+async def test_400(jp_file_contents_manager_class, tmp_path):  # noqa
     # Test Delete behavior
     # Test delete of file in hidden directory
     td = str(tmp_path)
@@ -369,7 +405,6 @@ async def test_400(jp_file_contents_manager_class, tmp_path):
     assert excinfo.value.status_code == 400
 
 
-@pytest.mark.skipif(sys.platform.startswith("win"), reason="Can't test hidden files on Windows")
 async def test_404(jp_file_contents_manager_class, tmp_path):
     # Test visible file in hidden folder
     with pytest.raises(HTTPError) as excinfo:
@@ -503,7 +538,7 @@ async def test_modified_date(jp_contents_manager):
     assert renamed["last_modified"] >= saved["last_modified"]
 
 
-async def test_get(jp_contents_manager):
+async def test_get(jp_contents_manager):  # noqa
     cm = jp_contents_manager
     # Create a notebook
     model = await ensure_async(cm.new_untitled(type="notebook"))
@@ -815,6 +850,55 @@ async def test_copy(jp_contents_manager):
     assert copy3["path"] == "copy 3.ipynb"
 
 
+async def test_copy_dir(jp_contents_manager):
+    cm = jp_contents_manager
+    destDir = "Untitled Folder 1"
+    sourceDir = "Morningstar Notebooks"
+    nonExistantDir = "FolderDoesNotExist"
+
+    _make_dir(cm, destDir)
+    _make_dir(cm, sourceDir)
+
+    nestedDir = f"{destDir}/{sourceDir}"
+
+    # copy one folder insider another folder
+    copy = await ensure_async(cm.copy(from_path=sourceDir, to_path=destDir))
+    assert copy["path"] == nestedDir
+
+    # need to test when copying in a directory where the another folder with the same name exists
+    _make_dir(cm, nestedDir)
+    copy = await ensure_async(cm.copy(from_path=sourceDir, to_path=destDir))
+    assert copy["path"] == f"{nestedDir}-Copy1"
+
+    # need to test for when copying in the same path as the sourceDir
+    copy = await ensure_async(cm.copy(from_path=sourceDir, to_path=""))
+    assert copy["path"] == f"{sourceDir}-Copy1"
+
+    # ensure its still possible to copy a folder to another folder that doesn't exist
+    copy = await ensure_async(
+        cm.copy(
+            from_path=sourceDir,
+            to_path=nonExistantDir,
+        )
+    )
+    assert copy["path"] == f"{nonExistantDir}/{sourceDir}"
+
+
+async def test_copy_big_dir(jp_contents_manager):
+    # this tests how the Content API limits preventing copying folders that are more than
+    # the size limit specified in max_copy_folder_size_mb trait
+    cm = jp_contents_manager
+    destDir = "Untitled Folder 1"
+    sourceDir = "Morningstar Notebooks"
+    cm.max_copy_folder_size_mb = 5
+    _make_dir(cm, destDir)
+    _make_big_dir(contents_manager=cm, api_path=sourceDir)
+    with pytest.raises(HTTPError) as exc_info:
+        await ensure_async(cm.copy(from_path=sourceDir, to_path=destDir))
+
+    assert exc_info.type is HTTPError
+
+
 async def test_mark_trusted_cells(jp_contents_manager):
     cm = jp_contents_manager
     nb, name, path = await new_notebook(cm)
@@ -924,3 +1008,43 @@ async def test_validate_notebook_model(jp_contents_manager):
         cm.validate_notebook_model(model)
         assert mock_validate_nb.call_count == 1
         mock_validate_nb.reset_mock()
+
+
+@patch(
+    "jupyter_core.paths.is_hidden",
+    side_effect=AssertionError("Should not call is_hidden if not important"),
+)
+@patch(
+    "jupyter_server.services.contents.filemanager.is_hidden",
+    side_effect=AssertionError("Should not call is_hidden if not important"),
+)
+async def test_regression_is_hidden(m1, m2, jp_contents_manager):
+    cm = jp_contents_manager
+    cm.allow_hidden = True
+    # Our role here is to check that the side-effect never triggers
+    dirname = "foo/.hidden_dir"
+    await make_populated_dir(cm, dirname)
+    await ensure_async(cm.get(dirname))
+    await check_populated_dir_files(cm, dirname)
+    await ensure_async(cm.get(path="/".join([dirname, "nb.ipynb"])))
+    await ensure_async(cm.get(path="/".join([dirname, "file.txt"])))
+    await ensure_async(cm.new(path="/".join([dirname, "nb2.ipynb"])))
+    await ensure_async(cm.new(path="/".join([dirname, "file2.txt"])))
+    await ensure_async(cm.new(path="/".join([dirname, "subdir"]), model={"type": "directory"}))
+    await ensure_async(
+        cm.copy(
+            from_path="/".join([dirname, "file.txt"]), to_path="/".join([dirname, "file-copy.txt"])
+        )
+    )
+    await ensure_async(
+        cm.rename_file(
+            old_path="/".join([dirname, "file-copy.txt"]),
+            new_path="/".join([dirname, "file-renamed.txt"]),
+        )
+    )
+    await ensure_async(cm.delete_file(path="/".join([dirname, "file-renamed.txt"])))
+
+    # sanity check that is actually triggers when flag set to false
+    cm.allow_hidden = False
+    with pytest.raises(AssertionError):
+        await ensure_async(cm.get(dirname))
