@@ -1,13 +1,16 @@
 import json
 
 import pytest
-import tornado
-from jupyter_client.kernelspec import NATIVE_KERNEL_NAME
+from tornado.httpclient import HTTPClientError
+
+from jupyter_server.serverapp import ServerApp
 
 from ...utils import expected_http_error, some_resource
 
 
-async def test_list_kernelspecs_bad(jp_fetch, jp_kernelspecs, jp_data_dir):
+async def test_list_kernelspecs_bad(jp_fetch, jp_kernelspecs, jp_data_dir, jp_serverapp):
+    app: ServerApp = jp_serverapp
+    default = app.kernel_manager.default_kernel_name
     bad_kernel_dir = jp_data_dir.joinpath(jp_data_dir, "kernels", "bad2")
     bad_kernel_dir.mkdir(parents=True)
     bad_kernel_json = bad_kernel_dir.joinpath("kernel.json")
@@ -16,17 +19,19 @@ async def test_list_kernelspecs_bad(jp_fetch, jp_kernelspecs, jp_data_dir):
     r = await jp_fetch("api", "kernelspecs", method="GET")
     model = json.loads(r.body.decode())
     assert isinstance(model, dict)
-    assert model["default"] == NATIVE_KERNEL_NAME
+    assert model["default"] == default
     specs = model["kernelspecs"]
     assert isinstance(specs, dict)
     assert len(specs) > 2
 
 
-async def test_list_kernelspecs(jp_fetch, jp_kernelspecs):
+async def test_list_kernelspecs(jp_fetch, jp_kernelspecs, jp_serverapp):
+    app: ServerApp = jp_serverapp
+    default = app.kernel_manager.default_kernel_name
     r = await jp_fetch("api", "kernelspecs", method="GET")
     model = json.loads(r.body.decode())
     assert isinstance(model, dict)
-    assert model["default"] == NATIVE_KERNEL_NAME
+    assert model["default"] == default
     specs = model["kernelspecs"]
     assert isinstance(specs, dict)
     assert len(specs) > 2
@@ -35,7 +40,7 @@ async def test_list_kernelspecs(jp_fetch, jp_kernelspecs):
         return s["name"] == "sample" and s["spec"]["display_name"] == "Test kernel"
 
     def is_default_kernelspec(s):
-        return s["name"] == NATIVE_KERNEL_NAME and s["spec"]["display_name"].startswith("Python")
+        return s["name"] == default
 
     assert any(is_sample_kernelspec(s) for s in specs.values()), specs
     assert any(is_default_kernelspec(s) for s in specs.values()), specs
@@ -51,7 +56,7 @@ async def test_get_kernelspecs(jp_fetch, jp_kernelspecs):
 
 
 async def test_get_nonexistant_kernelspec(jp_fetch, jp_kernelspecs):
-    with pytest.raises(tornado.httpclient.HTTPClientError) as e:
+    with pytest.raises(HTTPClientError) as e:
         await jp_fetch("api", "kernelspecs", "nonexistant", method="GET")
     assert expected_http_error(e, 404)
 
@@ -63,10 +68,10 @@ async def test_get_kernel_resource_file(jp_fetch, jp_kernelspecs):
 
 
 async def test_get_nonexistant_resource(jp_fetch, jp_kernelspecs):
-    with pytest.raises(tornado.httpclient.HTTPClientError) as e:
+    with pytest.raises(HTTPClientError) as e:
         await jp_fetch("kernelspecs", "nonexistant", "resource.txt", method="GET")
     assert expected_http_error(e, 404)
 
-    with pytest.raises(tornado.httpclient.HTTPClientError) as e:
+    with pytest.raises(HTTPClientError) as e:
         await jp_fetch("kernelspecs", "sample", "nonexistant.txt", method="GET")
     assert expected_http_error(e, 404)
